==> crypt-core-4.16.0-sources.jar: de/alpharogroup/crypto/io/CryptoOutputStream.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.io;

import java.io.OutputStream;

import javax.crypto.CipherOutputStream;

import de.alpharogroup.crypto.core.BaseStringDecryptor;

/**
 * The class {@link CryptoOutputStream} extends the {@link CipherOutputStream}.
 *
 * @author Asterios Raptis
 * @version 1.0
 */
public class CryptoOutputStream extends CipherOutputStream
{

	/**
	 * Instantiates a new {@link CryptoOutputStream}.
	 *
	 * @param out
	 *            the out
	 * @param decryptor
	 *            the decryptor
	 */
	public CryptoOutputStream(final OutputStream out, final BaseStringDecryptor decryptor)
	{
		super(out, decryptor.getModel().getCipher());
	}

}

==> crypt-core-5.0.0-sources.jar: de/alpharogroup/crypto/io/CryptoOutputStream.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.io;

import java.io.OutputStream;

import javax.crypto.CipherOutputStream;

import de.alpharogroup.crypto.core.AbstractStringDecryptor;

/**
 * The class {@link CryptoOutputStream} extends the {@link CipherOutputStream}.
 *
 * @author Asterios Raptis
 * @version 1.0
 */
public class CryptoOutputStream extends CipherOutputStream
{

	/**
	 * Instantiates a new {@link CryptoOutputStream}.
	 *
	 * @param out
	 *            the out
	 * @param decryptor
	 *            the decryptor
	 */
	public CryptoOutputStream(final OutputStream out, final AbstractStringDecryptor decryptor)
	{
		super(out, decryptor.getModel().getCipher());
	}

}
